==> ccx_1.5.src.tar.bz2: CalculiX/ccx_1.5/src/ident2.f <==
!
!     CalculiX - A 3-dimensional finite element program
!              Copyright (C) 1998-2005 Guido Dhondt
!
!     This program is free software; you can redistribute it and/or
!     modify it under the terms of the GNU General Public License as
!     published by the Free Software Foundation(version 2);
!     
!
!     This program is distributed in the hope that it will be useful,
!     but WITHOUT ANY WARRANTY; without even the implied warranty of 
!     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the 
!     GNU General Public License for more details.
!
!     You should have received a copy of the GNU General Public License
!     along with this program; if not, write to the Free Software
!     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
!
!                                                                             
!     identifies the position id of px in an ordered array
!     x of real numbers; The numbers in x are at positions
!     1, 1+ninc, 1+2*ninc, 1+3*ninc... up to 1+(n-1)*ninc
!  
!     id is such that x(id).le.px and x(id+1).gt.px
!                                                                             
      SUBROUTINE IDENT2(X,PX,N,ninc,ID)                                               
      IMPLICIT REAL*8 (A-H,O-Z)                                                
      DIMENSION X(N*ninc) 
      if(n.eq.0) then
         id=0
         return
      endif
      N1=0                                                                      
      N2=N+1                                                                    
      DO 1 I=1,5000                                                             
      M=(N2+N1)/2                                                               
      IF(PX.GE.X(1+ninc*(M-1))) N1=M                                                       
      IF(PX.LT.X(1+ninc*(M-1))) N2=M                                                       
      IF((N2-N1).EQ.1) GO TO 2                                                  
1     CONTINUE                                                                  
2     ID=N1                                                                     
      RETURN                                                                    
      END

==> ccx_1.7.src.tar.bz2: CalculiX/ccx_1.7/src/ident2.f <==
!
!     CalculiX - A 3-dimensional finite element program
!              Copyright (C) 1998-2007 Guido Dhondt
!
!     This program is free software; you can redistribute it and/or
!     modify it under the terms of the GNU General Public License as
!     published by the Free Software Foundation(version 2);
!     
!
!     This program is distributed in the hope that it will be useful,
!     but WITHOUT ANY WARRANTY; without even the implied warranty of 
!     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the 
!     GNU General Public License for more details.
!
!     You should have received a copy of the GNU General Public License
!     along with this program; if not, write to the Free Software
!     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
!
!                                                                             
!     identifies the position id of px in an ordered array
!     x of real numbers; The numbers in x are at positions
!     1, 1+ninc, 1+2*ninc, 1+3*ninc... up to 1+(n-1)*ninc
!  
!     id is such that x(id).le.px and x(id+1).gt.px
!                                                                             
      SUBROUTINE IDENT2(X,PX,N,ninc,ID)
      IMPLICIT none    
      integer n,id,n2,m,ninc
      real*8 X(N*ninc),px
      id=0
      if(n.eq.0) return
      N2=N+1
      DO                                                            
         M=(N2+ID)/2
         IF(PX.GE.X(1+ninc*(M-1))) then
            ID=M      
         else
            N2=M            
         endif
         IF((N2-ID).EQ.1) return
      enddo
      END
